@@ -166,7 +166,7 @@ class Migration(migrations.Migration):
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("device",
-                 models.OneToOneField(on_delete=models.deletion.CASCADE, related_name="device_physicalvolume",
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="device_physicalvolume",
                                       to="netbox_storage.partition")),
                 ("vg",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="volumegroup_physicalvolume",
